﻿//A WPF grafikához a következő referenciákat vettük fel:
//PresentationCore
//PresentationFramework
//WindowsBase
//System.Xaml ha .NET >= 4.0

using System;
using System.Collections.Generic;
using System.Linq;
using System.IO; //File-kezeléshez

using System.Windows; //WPF Grafikához
using System.Windows.Controls; //WPF Grafikához
using System.Windows.Shapes; //WPF Grafikához
using System.Windows.Media; //WPF Grafikához
using System.Windows.Controls.Primitives; //WPF Grafikához

namespace Erettsegi21_Szin_kep
{
    class KPont
    {
        public int x { get; set; } //oszlop
        public int y { get; set; } //sor
        public int R { get; set; }
        public int G { get; set; }
        public int B { get; set; }
        public bool Vörös { get { return R == 255 && G == 0 && B == 0; } }
        public bool Zöld { get { return R == 0 && G == 255 && B == 0; } }
        public bool Kék { get { return R == 0 && G == 0 && B == 255; } }
        public bool Sárga { get { return R == 255 && G == 255 && B == 0; } }
       
        public KPont(int x, int y, string RGB)
        {
            this.x = x;
            this.y = y;
            R = byte.Parse(RGB.Split(' ')[0]);
            G = byte.Parse(RGB.Split(' ')[1]);
            B = byte.Parse(RGB.Split(' ')[2]);
        }

        public override bool Equals(object obj)
        {
            KPont p = (KPont)obj;
            return this.R == p.R && this.G == p.G && this.B == p.B;
        }

        public override int GetHashCode()
        {
            return x << 28 & y << 24 & R << 16 & G << 8 & B;
        }

        public override string ToString()
        {
            return string.Format("{0} {1} {2}", R, G, B);
        }

    }

    
    class Program
    {
        //A Grafika metódus nem a feladatmegoldás része!
        static void Grafika(List<KPont> kép)
        {
            int méret = (int)(SystemParameters.PrimaryScreenHeight * 0.8);
            Window MyW = new Window() { Width = méret, Height = méret, Top = 0, Left = SystemParameters.PrimaryScreenWidth - méret }; //ablak
            UniformGrid MyUG = new UniformGrid() { Rows = 50, Columns = 50 }; //UniformGrid-re "rajzolunk"
            foreach (var i in kép) MyUG.Children.Add(new Label() { Background = new SolidColorBrush(new Color() { A = 255, R = (byte)i.R, G = (byte)i.G, B = (byte)i.B }) });
            MyW.Content = MyUG;
            MyW.ShowDialog();
        }



        [STAThread] //WPF Grafikához (Nem része a feladatnak!)
        static void Main()
        {
            Console.WriteLine("1. feladat: Beolvasás (Zárja be a grafikát a folytatáshoz!)");
            string[] forrás = File.ReadAllLines("kep.txt");
            List<KPont> Kép = new List<KPont>();
            for (int i = 0; i < forrás.Length; i++) Kép.Add(new KPont(i%50+1,i/50+1,forrás[i]));
            
            //WPF Grafika (Nem része a feladatnak!)
            Grafika(Kép);

            Console.WriteLine("2. feladat: Kérem az RGB kódot R G B sorrendben, szóközzel elválasztva:");
            Console.Write("A szín {0} a képen!", Kép.Contains(new KPont(0, 0, Console.ReadLine())) ? "megtalálható" : "nem található meg");

            var szín_35_8 = Kép.Where(b => b.x == 8 && b.y == 35).First();
            Console.WriteLine("\n3. feladat: Sorban:{0} Oszlopban:{1}", Kép.Where(a => a.y == 35 && a.Equals(szín_35_8)).Count(), Kép.Where(a => a.x == 8 && a.Equals(szín_35_8)).Count());

            Dictionary<string, int> szinek = new Dictionary<string, int>() { { "Vörös", Kép.Count(a => a.Vörös) }, { "Zöld", Kép.Count(a => a.Zöld) }, { "Kék", Kép.Count(a => a.Kék) } };
            Console.WriteLine("4. feladat: {0}", szinek.OrderByDescending(a => a.Value).First().Key);

            Console.WriteLine("5. feladat: Keretez");
            var keret = Kép.Where(a => a.x < 4 || a.x > 47 || a.y < 4 || a.y > 47);
            foreach (var i in keret) { i.R = 0; i.G = 0; i.B = 0;}

            Console.WriteLine("6. feladat: keretes.txt");
            File.WriteAllLines("keretes.txt", Kép.Select(x=>x.ToString()).ToArray());

            Console.WriteLine("7. feladat: Sárga téglalap  (Zárja be a grafikát a kilépéshez!)");
            var sárga=Kép.Where(a=>a.Sárga);
            Console.WriteLine("Kezd: {0}, {1}", sárga.First().y, sárga.First().x);
            Console.WriteLine("Vége: {0}, {1}", sárga.Last().y, sárga.Last().x);
            Console.WriteLine("Képpontok száma: {0}", sárga.Count());

            //WPF Grafika (Nem része a feladatnak!)
            Grafika(Kép);
        }
    }
}
